#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["install_requires"]
import os
from os.path import *


dir = dirname(dirname(__file__))
if not dir: dir="."

install_requires = []
# skip if ~/.no_install_requires exists
no_install_requires = join(os.environ["HOME"],".no_install_requires")
if exists(no_install_requires):
	for name in ["requirements.txt","requires.txt","install_requires.txt"]:
	    file = join(dir,name)
	    if exists(file):
	        lines = open(file).read().splitlines()
	        lines = list(filter(lambda l:l.lstrip().rstrip(),lines))
	        install_requires=lines

	if __name__=="__main__":
	    for k in __all__:
	        if k in globals():
	            print("%s: %s" % (k,globals()[k]))
else:
	print("%s: SKIP ~/.no_install_requires" % __file__)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["scripts"]
import os
from os.path import *

dir = dirname(dirname(__file__))
if not dir: dir="."

file = join(dir,"scripts.txt")
if exists(file) and isfile(file): # ./url.txt
    scripts = open(file).read().lstrip().rstrip().splitlines()
else:
    path  = join(dir,"scripts")
    if exists(path) and isdir(file):
        scripts = list(map(lambda name:join("scripts",name),
            list(filter(lambda f:isfile(join(path,f)) and f.find(" ")<0,
                os.listdir(path)
            ))
        ))

if __name__=="__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k,globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
try:
    import __builtin__  as __builtins__ # python 2
except:
    import builtins as __builtins__ # python 3
from datetime import *
from json import *
from public import *
from self import *

def isdict(object):
    return isinstance(object,dict)

@public
class dict(dict):
    def __init__(self, *args, **kwargs):
        self.update(*args, **kwargs)

    def get(self,key=None,default=None,i=False):
        result = __builtins__.dict.get(self,key,default)
        if result is None and i==True: # insensitive
            for k in self.keys():
                if str(key).lower()==str(k).lower():
                   return self[k]
        return result

    @self
    def update(self,*args,**kwargs):
        __builtins__.dict.update(self,*args,**kwargs)

    @property
    def json(self):
        """return json string"""
        dthandler = lambda i: i.isoformat() if isinstance(i,datetime) else None
        return dumps(
            self.__dict__,
            dthandler
        )

    @self
    def remove(self,v):
        """remove element(s) by key"""
        if isinstance(v,list): # list
            map(self.remove,v)
        else:
            if v in self:
                del self[v]

    def __getattribute__(self,name):
        if hasattr(type(self),name):
            return object.__getattribute__(self,name)
        if name in self:
            if isinstance(self[name],dict): # dict
                return dict(self[name])
            return self[name]

    def __getitem__(self,key): 
        if key in self:
            v = __builtins__.dict.__getitem__(self,key)
            if isdict(v): # recirsive
                return type(self)(v)
            return v

    def __setattr__(self, name, value):
        if hasattr(type(self),name):
            object.__setattr__(self,name,value)
        else:
            self[name] =  value

if __name__=="__main__":
    print(dict(key="v")["key"]) # v
    print(dict(key="v").key) # v
    print(dict(key="v")["not-existing"]) # None
    print(dict(key="v").not_existing) # None
    dict().remove("not-existing")
    dict().remove("not-existing").remove("not-existing2") # 
    dict().remove(["not-existing","not-existing2"]) # 



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["version"]
from os.path import *

dir = dirname(dirname(__file__))
if not dir: dir="."

# ./version or ./version.txt
for name in ["version","version.txt"]:
    file = join(dir,name)
    if exists(file) and isfile(file):
        version = open(file).read().lstrip().rstrip()

if __name__=="__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k,globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["classifiers"]
import os
from os.path import *

dir = dirname(dirname(__file__))
if not dir: dir="."

def read(path):
    if exists(path) and isfile(path):
        lines = open(path).read().splitlines()
        lines = list(filter(lambda l:l.lstrip().rstrip(),lines))
        lines = list(filter(lambda l:l,lines))
        return lines
    return []

classifiers = []
# ~/.classifiers.txt (default)
default = read(join(os.environ["HOME"],".classifiers.txt"))
# ./.classifiers.txt, ./classifiers.txt (custom, override default)
custom=read(".classifiers.txt")+read("classifiers.txt")
for l in custom:
    if l.find(" :: ")>0:
        k = l.split(" :: ")[0]
        default = list(filter(lambda l:l.find(k)!=0,default))
classifiers=default+custom
classifiers.sort()

if __name__=="__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k,globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["platforms"]
from os.path import *

dir = dirname(dirname(__file__))
if not dir: dir="."

file = join(dir,"platforms.txt")
platforms="any" # default
if exists(file):
    platforms = open(file).read().lstrip().rstrip()

if __name__=="__main__":
	for k in __all__:
		if k in globals():
			print("%s: %s" % (k,globals()[k]))

